==> redquicklib-1.500.0.tgz: package/lib/redservice.js <==
import * as RedService from '../index';
import { Parameters } from '../index';
import * as Globals from './globals';

const endpoints = {
    GetDefaultDefinition: (objectType) => `api/${objectType}/ui/default`,
    GetUIDefinition: (objectType) => `api/${objectType}/ui/definition`,
    GetAll: (objectType) => `api/${objectType}/all`,
    GetRedObject: (objectType, id) => `api/${objectType}/get/${id}`,
    UpdateRedObject: (objectType, id) => `api/${objectType}/update/${id}`,
    DeleteRedObject: (objectType, id) => `api/${objectType}/delete/${id}`,
    CreateRedObject: (objectType) => `api/${objectType}/create`,
}

var formatjson = '?format=json';
var redservice = RedService.CreateRedService(Globals.DEFAULT_URL);

export default {
    getWebRTC: async () => {
        return redservice.get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return redservice.get(Parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice.post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return redservice.post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return redservice.get(Parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return redservice.delete(Parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return redservice.post(Parameters(endpoints.EmitMessage, to), body);
    },
    getUIDefinition: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('ui') ? endpointOverrides('ui') : endpoints.GetUIDefinition(objectType);
        return redservice.get(endpoint);
    },
    getUIDefault: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('default') ? endpointOverrides('default') : endpoints.GetDefaultDefinition(objectType);
        return redservice.get(endpoint);
    },
    getRedObject: async (args) => {
        var { objectType, id, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('get') ? endpointOverrides('get') : endpoints.GetRedObject(objectType, id);
        return redservice.get(endpoint);
    },
    getAllRedObject: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('all') ? endpointOverrides('all') : endpoints.GetAll(objectType);
        return redservice.get(endpoint);
    },
    updateRedObject: async (args) => {
        var { objectType, id, obj, endpointOverrides } = args;
        var body = (obj);
        var endpoint = endpointOverrides && endpointOverrides('update') ? endpointOverrides('update') : endpoints.UpdateRedObject(objectType, id);
        return redservice.put(endpoint, body);
    },
    createRedObject: async (args) => {
        var { objectType, obj, endpointOverrides } = args;
        var body = (obj);
        var endpoint = endpointOverrides && endpointOverrides('create') ? endpointOverrides('create') : endpoints.CreateRedObject(objectType);
        return redservice.post(endpoint, body);
    },
    deleteRedObject: async (args) => {
        var { objectType, id, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('delete') ? endpointOverrides('delete') : endpoints.DeleteRedObject(objectType, id);
        return redservice.delete(endpoint);
    }
}

==> redquicklib-1.662.0.tgz: package/lib/redservice.js <==
import * as RedService from '../index';
import { Parameters } from '../index';
import * as Globals from './globals';

const endpoints = {
    GetDefaultDefinition: (objectType) => `api/${objectType}/ui/default`,
    GetUIDefinition: (objectType) => `api/${objectType}/ui/definition`,
    GetAll: (objectType) => `api/${objectType}/all`,
    GetRedObject: (objectType, id) => `api/${objectType}/get/${id}`,
    UpdateRedObject: (objectType, id) => `api/${objectType}/update/${id}`,
    DeleteRedObject: (objectType, id) => `api/${objectType}/delete/${id}`,
    CreateRedObject: (objectType) => `api/${objectType}/create`,
}

var formatjson = '?format=json';
var _redservice; // RedService.CreateRedService(Globals.DEFAULT_URL);
function redservice() {
    _redservice = _redservice || RedService.CreateRedService(Globals.DEFAULT_URL)
    return _redservice;
}
export default {
    getWebRTC: async () => {
        return redservice().get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return redservice().get(Parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice().post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return redservice().post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return redservice().post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return redservice().get(Parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return redservice().delete(Parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return redservice().post(Parameters(endpoints.EmitMessage, to), body);
    },
    getUIDefinition: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('ui') ? endpointOverrides('ui') : endpoints.GetUIDefinition(objectType);
        return redservice().get(endpoint);
    },
    getUIDefault: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('default') ? endpointOverrides('default') : endpoints.GetDefaultDefinition(objectType);
        return redservice().get(endpoint);
    },
    getRedObject: async (args) => {
        var { objectType, id, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('get') ? endpointOverrides('get') : endpoints.GetRedObject(objectType, id);
        return redservice().get(endpoint);
    },
    getAllRedObject: async (args) => {
        var { objectType, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('all') ? endpointOverrides('all') : endpoints.GetAll(objectType);
        return redservice().get(endpoint);
    },
    updateRedObject: async (args) => {
        var { objectType, id, obj, endpointOverrides } = args;
        var body = (obj);
        var endpoint = endpointOverrides && endpointOverrides('update') ? endpointOverrides('update') : endpoints.UpdateRedObject(objectType, id);
        return redservice().put(endpoint, body);
    },
    createRedObject: async (args) => {
        var { objectType, obj, endpointOverrides } = args;
        var body = (obj);
        var endpoint = endpointOverrides && endpointOverrides('create') ? endpointOverrides('create') : endpoints.CreateRedObject(objectType);
        return redservice().post(endpoint, body);
    },
    deleteRedObject: async (args) => {
        var { objectType, id, endpointOverrides } = args;
        var endpoint = endpointOverrides && endpointOverrides('delete') ? endpointOverrides('delete') : endpoints.DeleteRedObject(objectType, id);
        return redservice().delete(endpoint);
    }
}
